@@ -37,11 +37,11 @@ public:
     
 protected:
   //Overrides of default signal handlers:
-  virtual void on_activate() override;
-  virtual void on_startup() override;
-  virtual void on_open(const Gio::Application::type_vec_files& files,
+  void on_activate() override;
+  void on_startup() override;
+  void on_open(const Gio::Application::type_vec_files& files,
     const Glib::ustring& hint) override;
-  virtual int on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine>& command_line) override;
+  int on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine>& command_line) override;
 
 private:
   void create_window(const Glib::RefPtr<Gio::File>& file = Glib::RefPtr<Gio::File>());
