@@ -456,8 +456,6 @@ void AppWindow::on_menu_help_about()
   {
     //Re-create About box:
     delete m_pAbout;
-    m_pAbout = nullptr;
-
     m_pAbout = new Gtk::AboutDialog;
 
     m_pAbout->set_program_name(m_strAppName);
@@ -1478,7 +1476,7 @@ void AppWindow::set_mode_find()
 
 void AppWindow::on_menu_help_contents()
 {
-  Glom::UiUtils::show_help(this);
+  Glom::UiUtils::show_help();
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -1512,47 +1510,22 @@ bool AppWindow::recreate_database_from_example(bool& user_cancelled)
     return false;
 
   connection_pool->set_database(db_name);
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
-#else
-  std::shared_ptr<std::exception> error;
-#endif // GLIBMM_EXCEPTIONS_ENABLED
   {
     connection_pool->set_ready_to_connect(); //This has succeeded already.
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     std::shared_ptr<SharedConnection> sharedconnection = connection_pool->connect();
-#else
-    std::shared_ptr<SharedConnection> sharedconnection = connection_pool->connect(error);
-    if(!error.get())
-    {
-#endif // GLIBMM_EXCEPTIONS_ENABLED
-      std::cerr << G_STRFUNC << ": Failed because database exists already." << std::endl;
+    std::cerr << G_STRFUNC << ": Failed because database exists already." << std::endl;
 
-      return false; //Connection to the database succeeded, because no exception was thrown. so the database exists already.
-#ifndef GLIBMM_EXCEPTIONS_ENABLED
-    }
-#endif // !GLIBMM_EXCEPTIONS_ENABLED
+    return false; //Connection to the database succeeded, because no exception was thrown. so the database exists already.
   }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   catch(const ExceptionConnection& ex)
   {
-#else
-  if(error.get())
-  {
-    const auto exptr = dynamic_cast<ExceptionConnection*>(error.get());
-    if(exptr)
+    if(ex.get_failure_type() == ExceptionConnection::failure_type::NO_SERVER)
     {
-      const ExceptionConnection& ex = *exptr;
-#endif // GLIBMM_EXCEPTIONS_ENABLED
-      if(ex.get_failure_type() == ExceptionConnection::failure_type::NO_SERVER)
-      {
-        user_cancelled = true; //Eventually, the user will cancel after retrying.
-        std::cerr << G_STRFUNC << ": Failed because connection to server failed, without specifying a database." << std::endl;
-        return false;
-      }
-#ifndef GLIBMM_EXCEPTIONS_ENABLED
+      user_cancelled = true; //Eventually, the user will cancel after retrying.
+      std::cerr << G_STRFUNC << ": Failed because connection to server failed, without specifying a database." << std::endl;
+      return false;
     }
-#endif // !GLIBMM_EXCEPTIONS_ENABLED
 
     //Otherwise continue, because we _expected_ connect() to fail if the db does not exist yet.
   }
@@ -1579,26 +1552,13 @@ bool AppWindow::recreate_database_from_example(bool& user_cancelled)
   BusyCursor busy_cursor(this);
 
   std::shared_ptr<SharedConnection> sharedconnection;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
-#endif // GLIBMM_EXCEPTIONS_ENABLED
   {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     sharedconnection = connection_pool->connect();
-#else
-    sharedconnection = connection_pool->connect(error);
-    if(!error.get())
-#endif // GLIBMM_EXCEPTIONS_ENABLED
-      connection_pool->set_database(db_name); //The database was successfully created, so specify it when connecting from now on.
+    connection_pool->set_database(db_name); //The database was successfully created, so specify it when connecting from now on.
   }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   catch(const ExceptionConnection& ex)
   {
-#else
-  if(error.get())
-  {
-    const auto ex = *error.get();
-#endif // GLIBMM_EXCEPTIONS_ENABLED
     std::cerr << G_STRFUNC << ": Failed to connect to the newly-created database." << std::endl;
     return false;
   }
@@ -1694,47 +1654,22 @@ bool AppWindow::recreate_database_from_backup(const std::string& backup_data_fil
     return false;
 
   connection_pool->set_database(db_name);
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
-#else
-  std::shared_ptr<std::exception> error;
-#endif // GLIBMM_EXCEPTIONS_ENABLED
   {
     connection_pool->set_ready_to_connect(); //This has succeeded already.
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     std::shared_ptr<SharedConnection> sharedconnection = connection_pool->connect();
-#else
-    std::shared_ptr<SharedConnection> sharedconnection = connection_pool->connect(error);
-    if(!error.get())
-    {
-#endif // GLIBMM_EXCEPTIONS_ENABLED
-      std::cerr << G_STRFUNC << ": Failed because database exists already." << std::endl;
+    std::cerr << G_STRFUNC << ": Failed because database exists already." << std::endl;
 
-      return false; //Connection to the database succeeded, because no exception was thrown. so the database exists already.
-#ifndef GLIBMM_EXCEPTIONS_ENABLED
-    }
-#endif // !GLIBMM_EXCEPTIONS_ENABLED
+    return false; //Connection to the database succeeded, because no exception was thrown. so the database exists already.
   }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   catch(const ExceptionConnection& ex)
   {
-#else
-  if(error.get())
-  {
-    const auto exptr = dynamic_cast<ExceptionConnection*>(error.get());
-    if(exptr)
+    if(ex.get_failure_type() == ExceptionConnection::failure_type::NO_SERVER)
     {
-      const ExceptionConnection& ex = *exptr;
-#endif // GLIBMM_EXCEPTIONS_ENABLED
-      if(ex.get_failure_type() == ExceptionConnection::failure_type::NO_SERVER)
-      {
-        user_cancelled = true; //Eventually, the user will cancel after retrying.
-        std::cerr << G_STRFUNC << ": Failed because connection to server failed, without specifying a database." << std::endl;
-        return false;
-      }
-#ifndef GLIBMM_EXCEPTIONS_ENABLED
+      user_cancelled = true; //Eventually, the user will cancel after retrying.
+      std::cerr << G_STRFUNC << ": Failed because connection to server failed, without specifying a database." << std::endl;
+      return false;
     }
-#endif // !GLIBMM_EXCEPTIONS_ENABLED
 
     //Otherwise continue, because we _expected_ connect() to fail if the db does not exist yet.
   }
@@ -2332,6 +2267,7 @@ Glib::ustring AppWindow::ui_file_select_save(const Glib::ustring& old_file_uri)
   return Glib::ustring();
 }
 
+/*
 void AppWindow::stop_self_hosting_of_document_database()
 {
   auto pDocument = static_cast<Document*>(get_document());
@@ -2344,6 +2280,7 @@ void AppWindow::stop_self_hosting_of_document_database()
     connection_pool->cleanup( sigc::mem_fun(*this, &AppWindow::on_connection_close_progress ));
   }
 }
+*/
 
 void AppWindow::on_menu_developer_changelanguage()
 {
@@ -2534,11 +2471,10 @@ void AppWindow::document_history_add(const Glib::ustring& file_uri)
   if(file_uri.empty())
     return;
 
-  bool prevent = false;
   if(!file_uri.empty())
   {
-    prevent = (file_uri == m_example_uri);
-    if(prevent)
+    //Prevent saving of example file templates just because we opened them:
+    if(file_uri == m_example_uri)
       return;
   }
 
@@ -3004,13 +2940,4 @@ void AppWindow::on_menu_edit_find()
     m_pFrame->set_mode_data();
 }
 
-
-void AppWindow::on_recent_files_activate(Gtk::RecentChooser& chooser)
-{
-  const auto uri = chooser.get_current_uri();
-  const auto bTest = open_document(uri);
-  if(!bTest)
-    document_history_remove(uri);
-}
-
 } //namespace Glom
