@@ -68,7 +68,7 @@ public:
   AppWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~AppWindow();
 
-  virtual void init(); //Unique final overrider.
+  void init() override; //Unique final overrider.
 
   /**
    * @param restore Whether @a document_uri is a .tar.gz backup file to restore.
@@ -168,28 +168,28 @@ public:
   static AppWindow* get_appwindow();
 
   /// Overidden to add a widget in the middle, under the menu, instead of replacing the whole contents.
-  virtual void add(Gtk::Widget& child);
+  void add(Gtk::Widget& child) override;
 
   /// For instance, to create bold primary text for a dialog box, without marking the markup for translation.
   static Glib::ustring util_bold_message(const Glib::ustring& message);
 
 protected:
   void init_layout(); //Arranges the menu, toolbar, etc.
-  virtual void init_menus() override; //Override this to add more or different menus.
-  virtual void init_menus_file() override; //Call this from init_menus() to add the standard file menu.
-  virtual void init_menus_edit() override; //Call this from init_menus() to add the standard edit menu
+  void init_menus() override; //Override this to add more or different menus.
+  void init_menus_file() override; //Call this from init_menus() to add the standard file menu.
+  void init_menus_edit() override; //Call this from init_menus() to add the standard edit menu
 
-  virtual void on_hide() override;
+  void on_hide() override;
 
   //Overrides from AppWindow_WithDoc:
-  virtual void document_history_add(const Glib::ustring& file_uri); //overridden.
-  virtual void document_history_remove(const Glib::ustring& file_uri); //overridden.
-  virtual void update_window_title();
-  virtual void ui_warning(const Glib::ustring& text, const Glib::ustring& secondary_text);
-  virtual Glib::ustring ui_file_select_open(const Glib::ustring& starting_folder_uri = Glib::ustring());
-  virtual Glib::ustring ui_file_select_save(const Glib::ustring& old_file_uri);
-  virtual void ui_show_modification_status();
-  virtual enumSaveChanges ui_offer_to_save_changes();
+  void document_history_add(const Glib::ustring& file_uri) override;
+  void document_history_remove(const Glib::ustring& file_uri) override;
+  void update_window_title() override;
+  void ui_warning(const Glib::ustring& text, const Glib::ustring& secondary_text) override;
+  Glib::ustring ui_file_select_open(const Glib::ustring& starting_folder_uri = Glib::ustring()) override;
+  Glib::ustring ui_file_select_save(const Glib::ustring& old_file_uri) override;
+  void ui_show_modification_status() override;
+  enumSaveChanges ui_offer_to_save_changes() override;
 
 
   //Signal handlers:
@@ -197,16 +197,15 @@ protected:
   //Menus:
 
 
-  virtual void ui_hide();
-  virtual void ui_bring_to_front();
+  void ui_hide() override;
+  void ui_bring_to_front() override;
 
-  virtual bool on_delete_event(GdkEventAny* event) override;
+  bool on_delete_event(GdkEventAny* event) override;
 
   void on_menu_edit_copy_activate();
   void on_menu_edit_cut_activate();
   void on_menu_edit_paste_activate();
   void on_menu_edit_find();
-  void on_recent_files_activate(Gtk::RecentChooser& recent_chooser);
 
   //Menu Builder and Actions
   Glib::RefPtr<Gtk::Builder> m_builder;
@@ -224,12 +223,12 @@ protected:
   Glib::RefPtr<Gio::SimpleAction> m_action_save, m_action_saveas;
 
 protected:
-  virtual void ui_warning_load_failed(int failure_code = 0); //Override.
+  void ui_warning_load_failed(int failure_code = 0) override;
 
 private:
-  virtual void init_create_document() override;
-  virtual bool on_document_load() override;
-  virtual void on_document_close() override;
+  void init_create_document() override;
+  bool on_document_load() override;
+  void on_document_close() override;
 
   bool offer_new_or_existing();
 
@@ -263,14 +262,14 @@ private:
   bool recreate_database_from_backup(const std::string& backup_data_file_path, bool& user_cancelled); //return indicates success.
   void on_recreate_database_progress();
 
-  void stop_self_hosting_of_document_database();
+  //void stop_self_hosting_of_document_database();
 
   void on_connection_avahi_begin();
   void on_connection_avahi_progress();
   void on_connection_avahi_done();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  void on_menu_help_about();
+  void on_menu_help_about() override;
   void on_about_close();
 
 #ifndef G_OS_WIN32
@@ -281,7 +280,7 @@ private:
   Glib::ustring ui_file_select_open_with_browse(bool& browsed, EpcServiceInfo*& browsed_server, Glib::ustring& browsed_service_name, const Glib::ustring& starting_folder_uri = Glib::ustring());
 #endif // !G_OS_WIN32
 
-  virtual void new_instance(const Glib::ustring& uri = Glib::ustring()) override;
+  void new_instance(const Glib::ustring& uri = Glib::ustring()) override;
 
   void on_connection_create_database_progress();
   void on_connection_close_progress();
