@@ -51,14 +51,12 @@ public:
   //a virtual base class so they would otherwise need to do that.
 
   ///Don't forget to call init() too.
-  AppWindow(const Glib::ustring& appname = Glib::ustring()); 
+  explicit AppWindow(const Glib::ustring& appname = Glib::ustring());
 
   virtual ~AppWindow();
 
   virtual void init(); //Sets it up and shows it.
 
-  virtual Glib::ustring get_version() const;
-
   static void set_command_line_args(int argc, char** &argv); //Needed for session management.
 
   typedef sigc::signal<void> type_signal_hide;
