@@ -56,11 +56,11 @@ class AppWindow_WithDoc : public AppWindow
 {
 public: 
   ///Don't forget to call init() too.
-  AppWindow_WithDoc(const Glib::ustring& appname = ""); //TODO: appname when using get_derived_widget()
+  explicit AppWindow_WithDoc(const Glib::ustring& appname = ""); //TODO: appname when using get_derived_widget()
 
   virtual ~AppWindow_WithDoc();
 
-  virtual void init() override; //overridden to create document.
+  void init() override; //overridden to create document.
 
   enum class enumSaveChanges
   {
@@ -117,11 +117,11 @@ public:
   virtual void on_menu_file_saveas(); //signal handler.
   virtual void offer_saveas(); //For direct use.
   virtual void on_menu_file_save(); //signal handler.
-  virtual void on_menu_file_close();
+  void on_menu_file_close() override;
 
-  virtual void on_menu_edit_copy();
-  virtual void on_menu_edit_paste();
-  virtual void on_menu_edit_clear();
+  void on_menu_edit_copy() override;
+  void on_menu_edit_paste() override;
+  void on_menu_edit_clear() override;
 
 protected:
   //Document:
@@ -164,8 +164,6 @@ protected:
 
   virtual enumSaveChanges ui_offer_to_save_changes() = 0;
 
-  static Glib::ustring get_conf_fullkey(const Glib::ustring& key);
-
   //Document:
   Document* m_pDocument; //An instance of a derived type.
   bool m_bCloseAfterSave;
