@@ -31,7 +31,6 @@
 //#ifndef GLOM_ENABLE_CLIENT_ONLY
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_formatting.h>
-#include <glom/mode_design/layout/layout_item_dialogs/dialog_notebook.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_textobject.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_imageobject.h>
 //#endif // !GLOM_ENABLE_CLIENT_ONLY
@@ -508,32 +507,6 @@ std::shared_ptr<LayoutItem_Image> Base_DB::offer_imageobject(const std::shared_p
   return result;
 }
 
-std::shared_ptr<LayoutItem_Notebook> Base_DB::offer_notebook(const std::shared_ptr<LayoutItem_Notebook>& start_notebook, Gtk::Window* transient_for)
-{
-  std::shared_ptr<LayoutItem_Notebook> result = start_notebook;
-
-  Dialog_Notebook* dialog = nullptr;
-  Utils::get_glade_widget_derived_with_warning(dialog);
-  if(!dialog) //Unlikely and it already warns on stderr.
-    return result;
-
-  if(transient_for)
-    dialog->set_transient_for(*transient_for);
-
-  dialog->set_notebook(start_notebook);
-  //dialog->set_transient_for(*this);
-  const auto response = Glom::UiUtils::dialog_run_with_help(dialog);
-  dialog->hide();
-  if(response == Gtk::RESPONSE_OK)
-  {
-    //Get the chosen relationship:
-    result = dialog->get_notebook();
-  }
-
-  delete dialog;
-
-  return result;
-}
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 //static:
@@ -561,6 +534,31 @@ bool Base_DB::get_field_primary_key_index_for_fields(const type_vec_fields& fiel
   return false; //Not found.
 }
 
+//static:
+bool Base_DB::get_field_primary_key_index_for_fields(const type_vecLayoutFields& fields, guint& field_column)
+{
+  //Initialize input parameter:
+  field_column = 0;
+
+  //TODO_performance: Cache the primary key?
+  guint col = 0;
+  guint cols_count = fields.size();
+  while(col < cols_count)
+  {
+    if(fields[col]->get_full_field_details()->get_primary_key())
+    {
+      field_column = col;
+      return true;
+    }
+    else
+    {
+      ++col;
+    }
+  }
+
+  return false; //Not found.
+}
+
 std::shared_ptr<Field> Base_DB::get_field_primary_key_for_table(const Glib::ustring& table_name) const
 {
   const auto document = get_document();
@@ -718,8 +716,6 @@ Base_DB::type_vecConstLayoutFields Base_DB::get_table_fields_to_show_for_sequenc
     }
     else
     {
-      type_vec_fields vecFieldsInDocument = pDoc->get_table_fields(table_name);
-
       //We will show the fields that the document says we should:
       for(const auto& group : mapGroupSequence)
       {
@@ -779,7 +775,7 @@ void Base_DB::calculate_field_in_all_records(const Glib::ustring& table_name, co
     {
       field_in_record.m_key_value = primary_key_value;
 
-      m_FieldsCalculationInProgress.clear();
+      clear_fields_calculation_in_progress();
       calculate_field(field_in_record);
     }
   }
@@ -1108,7 +1104,7 @@ void Base_DB::do_calculations(const LayoutFieldInRecord& field_changed, bool fir
   if(first_calc_field)
   {
     //g_warning("  clearing m_FieldsCalculationInProgress");
-    m_FieldsCalculationInProgress.clear();
+    clear_fields_calculation_in_progress();
   }
 
   //Recalculate fields that are triggered by a change of this field's value, not including calculations that these calculations use.
@@ -1128,7 +1124,7 @@ void Base_DB::do_calculations(const LayoutFieldInRecord& field_changed, bool fir
   }
 
   if(first_calc_field)
-    m_FieldsCalculationInProgress.clear();
+    clear_fields_calculation_in_progress();
 }
 
 Base_DB::type_list_const_field_items Base_DB::get_calculated_fields(const Glib::ustring& table_name, const std::shared_ptr<const LayoutItem_Field>& field)
@@ -1519,6 +1515,11 @@ Glib::ustring Base_DB::get_active_layout_platform(Document* document)
   return result;
 }
 
+void Base_DB::clear_fields_calculation_in_progress()
+{
+  m_FieldsCalculationInProgress.clear();
+}
+
 
 
 } //namespace Glom
