@@ -61,13 +61,13 @@ public:
   /** Returns whether we are in developer mode.
    * Some functionality will be deactivated when not in developer mode.
    */
-  virtual AppState::userlevels get_userlevel() const;
-  virtual void set_userlevel(AppState::userlevels value);
+  AppState::userlevels get_userlevel() const;
+  void set_userlevel(AppState::userlevels value);
 
   static std::shared_ptr<SharedConnection> connect_to_server(Gtk::Window* parent_window = 0);
 
-  virtual void set_document(Document* pDocument) override; //View override
-  virtual void load_from_document() override; //View override
+  void set_document(Document* pDocument) override; //View override
+  void load_from_document() override; //View override
 
   std::shared_ptr<Field> change_column(const Glib::ustring& table_name, const std::shared_ptr<const Field>& field_old, const std::shared_ptr<const Field>& field, Gtk::Window* parent_window) const;
 
@@ -87,6 +87,8 @@ public:
 
 protected:
 
+  void clear_fields_calculation_in_progress();
+
   typedef std::list< std::shared_ptr<LayoutItem_Field> > type_list_field_items;
   typedef std::list< std::shared_ptr<const LayoutItem_Field> > type_list_const_field_items;
 
@@ -115,7 +117,6 @@ protected:
 
   std::shared_ptr<LayoutItem_Text> offer_textobject(const std::shared_ptr<LayoutItem_Text>& start_textobject, Gtk::Window* transient_for = 0, bool show_title = true);
   std::shared_ptr<LayoutItem_Image> offer_imageobject(const std::shared_ptr<LayoutItem_Image>& start_imageobject, Gtk::Window* transient_for = 0, bool show_title = true);
-  std::shared_ptr<LayoutItem_Notebook> offer_notebook(const std::shared_ptr<LayoutItem_Notebook>& start_notebook, Gtk::Window* transient_for = 0);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   bool get_relationship_exists(const Glib::ustring& table_name, const Glib::ustring& relationship_name);
@@ -139,9 +140,9 @@ protected:
     }
 
     FieldInRecord(const std::shared_ptr<const LayoutItem_Field>& layout_item, const Glib::ustring& parent_table_name, const std::shared_ptr<const Field>& parent_key, const Gnome::Gda::Value& key_value, const Document& document)
-    : m_key_value(key_value)
+    : m_field(layout_item->get_full_field_details()),
+      m_key_value(key_value)
     {
-      m_field = layout_item->get_full_field_details();
       m_table_name = layout_item->get_table_used(parent_table_name);
 
       //The key:
@@ -190,11 +191,11 @@ protected:
     {}
 
     LayoutFieldInRecord(const std::shared_ptr<const LayoutItem_Field>& layout_item, const Glib::ustring& parent_table_name, const std::shared_ptr<const Field>& parent_key, const Gnome::Gda::Value& key_value)
-    : m_key_value(key_value)
+    : m_table_name(parent_table_name),
+      m_field(layout_item),
+      m_key(parent_key),
+      m_key_value(key_value)
     {
-      m_field = layout_item;
-      m_table_name = parent_table_name;
-      m_key = parent_key;
     }
 
     LayoutFieldInRecord(const LayoutFieldInRecord& src) = delete;
@@ -292,6 +293,7 @@ protected:
   static Glib::RefPtr<Gnome::Gda::Connection> get_connection();
 
   static bool get_field_primary_key_index_for_fields(const type_vec_fields& fields, guint& field_column);
+  static bool get_field_primary_key_index_for_fields(const type_vecLayoutFields& fields, guint& field_column);
 
   typedef std::vector<Glib::ustring> type_vec_strings;
   static type_vec_strings util_vecStrings_from_Fields(const type_vec_fields& fields);
@@ -311,7 +313,7 @@ protected:
   static void handle_error(const std::exception& ex, Gtk::Window* parent); //TODO_port: This is probably useless now.
   static bool handle_error();
 
-protected:
+private:
   type_field_calcs m_FieldsCalculationInProgress; //Prevent circular calculations and recalculations.
 };
 
