@@ -76,7 +76,7 @@ public:
   }
 
 private:
-  virtual void on_start_element(const Glib::ustring& name, const AttributeList& attributes)
+  void on_start_element(const Glib::ustring& name, const AttributeList& attributes) override
   {
     if(m_title.empty()) // Already found name? Wait for parse_chunk() call to return.
     {
@@ -258,10 +258,9 @@ bool Dialog_ExistingOrNew::list_examples()
 {
   //std::cout << "debug: " << G_STRFUNC << ": path=" << path << std::endl;
 
-  const char* examples_dir = "/org/gnome/glom/examples/";
-
   try
   {
+    const char* examples_dir = "/org/gnome/glom/examples/";
     const auto examples = Gio::Resource::enumerate_children_global(examples_dir);
     
     bool example_found = false;
@@ -416,7 +415,7 @@ EpcServiceInfo* Dialog_ExistingOrNew::get_service_info() const
   else
     throw std::logic_error("Dialog_ExistingOrNew::get_service_info: action is not OPEN_REMOTE");
 
-  return 0;
+  return nullptr;
 }
 
 Glib::ustring Dialog_ExistingOrNew::get_service_name() const
@@ -767,28 +766,12 @@ void Dialog_ExistingOrNew::on_existing_row_activated(const Gtk::TreeModel::Path&
     on_select_clicked();
 }
 
-void Dialog_ExistingOrNew::on_existing_button_clicked(const Gtk::TreeModel::Path& path)
-{
-  m_existing_view->get_selection()->select(path);
-
-  if(m_select_button->is_sensitive())
-    on_select_clicked();
-}
-
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Dialog_ExistingOrNew::on_new_row_activated(const Gtk::TreeModel::Path& /* path */, Gtk::TreeViewColumn* /* column */)
 {
   if(m_select_button->is_sensitive())
     on_select_clicked();
 }
-
-void Dialog_ExistingOrNew::on_new_button_clicked(const Gtk::TreeModel::Path& path)
-{
-  m_new_view->get_selection()->select(path);
-
-  if(m_select_button->is_sensitive())
-    on_select_clicked();
-}
 #endif //GLOM_ENABLE_CLIENT_ONLY
 
 void Dialog_ExistingOrNew::on_select_clicked()
