@@ -137,8 +137,8 @@ public:
 
   void on_dialog_tables_hide();
 
-  virtual void set_document(Document* pDocument) override; //View override
-  virtual void load_from_document() override; //View override
+  void set_document(Document* pDocument) override; //View override
+  void load_from_document() override; //View override
 
   enum class enumModes
   {
@@ -189,7 +189,7 @@ public:
 
 private:
 
-  //virtual void set_document(Document* pDocument) override;
+  //void set_document(Document* pDocument) override;
 
   /** Show the table, possibly selecting a particular record, possibly showing that in the details tab. This allows table_name to be empty in which case no
    * table will be shown.
@@ -226,15 +226,13 @@ private:
 
   void alert_no_table();
 
-  void instantiate_dialog_connection();
-
   //Signal handlers:
   void on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clause);
   void on_button_quickfind();
   void on_button_find_all();
   void on_notebook_data_switch_page(Gtk::Widget* page);
   void on_notebook_data_record_details_requested(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);
-  void on_userlevel_changed(AppState::userlevels userlevel);
+  void on_userlevel_changed(AppState::userlevels userlevel) override;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_dialog_add_related_table_response(int response);
