@@ -76,7 +76,7 @@ public:
   bool get_rows_empty() const;
 
   // The nasty reference return is for performance.
-  const Glib::ustring& get_data(guint row, guint col);
+  const Glib::ustring& get_data(guint row, guint col) const;
 
   /**  Fetches the next row from the parser's cache. It will block until enough
     *  data was parsed to return a row. An empty row indicates the last row was
@@ -86,9 +86,6 @@ public:
   // client of this method to check for the parser's state/cache size.
   const type_row_strings fetch_next_row();
 
-  /// Resets the internal row index used for fetch_next_row().
-  void reset_row_index();
-
   // Signals:
   typedef sigc::signal<void, const Glib::ustring&> type_signal_file_read_error;
 
@@ -177,7 +174,7 @@ private:
   void on_file_read(const Glib::RefPtr<Gio::AsyncResult>& result, const Glib::RefPtr<Gio::File>& source);
   void copy_buffer_and_continue_reading(gssize size);
   void on_buffer_read(const Glib::RefPtr<Gio::AsyncResult>& result);
-  void on_file_query_info(const Glib::RefPtr<Gio::AsyncResult>& result, const Glib::RefPtr<Gio::File>& source);
+  void on_file_query_info(const Glib::RefPtr<Gio::AsyncResult>& result, const Glib::RefPtr<Gio::File>& source) const;
 
   void set_state(State state);
 
