@@ -330,7 +330,7 @@ std::shared_ptr<SharedConnection> ConnectionPool::connect()
 
       {
         //Allow get_meta_store_data() to succeed:
-        //Hopefully this (and the update_meta_store_table() calls) is all we need.
+        //Hopefully this (and the update_meta_store_for_table() calls) is all we need.
         //std::cout << "DEBUG: Calling update_meta_store_data_types() ..." << std::endl;
         try
         {
@@ -350,8 +350,26 @@ std::shared_ptr<SharedConnection> ConnectionPool::connect()
 
         //std::cout << "DEBUG: Calling update_meta_store_table_names() ..." << std::endl;
 
-        if(!update_meta_store_for_table_names()) {
-          std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed without an exception." << std::endl;
+        try
+        {
+          //update_meta_store_table_names() has been known to throw an exception.
+          //Glom is mostly unusable when it fails, but that's still better than a crash.
+          //std::cout << G_STRFUNC << ": Before update_meta_store_table_name()" << std::endl;
+          const auto test = m_refGdaConnection->update_meta_store_table_names(m_backend->get_public_schema_name());
+          if(!test && !m_fake_connection)
+          {
+            std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed without an exception." << std::endl;
+          }
+        }
+        catch(const Glib::Error& ex)
+        {
+          //If the connection was not opened, because it is a fake connection,
+          //then we should not be surprised that this fails,
+          //and a warning will only be useful later when get_meta_store_data() fails when used in get_table_names_from_database().
+          if(!m_fake_connection)
+          {
+            std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed: " << ex.what() << std::endl;
+          }
         }
         //std::cout << "DEBUG: ... update_meta_store_table_names() has finished." << std::endl;
 
@@ -692,7 +710,7 @@ bool ConnectionPool::connect_nothrow()
     }
   }
 
-  return (bool)m_refGdaConnection;
+  return (m_refGdaConnection != 0);
 }
 
 //TODO: Why do we use noexcept here and on change_columns()?
@@ -802,7 +820,7 @@ Document* ConnectionPool::get_document()
     //Don't bother warning because all the code that calls get_document() checks 
     //for 0 and responds reasonably.
     //std::cerr << G_STRFUNC << ": m_slot_get_document is null." << std::endl;
-    return 0;
+    return nullptr;
   }
 
   return m_slot_get_document();
@@ -814,11 +832,11 @@ EpcContents* ConnectionPool::on_publisher_document_requested(EpcPublisher* /* pu
 {
   auto connection_pool = static_cast<Glom::ConnectionPool*>(user_data);
   if(!connection_pool)
-    return 0;
+    return nullptr;
 
   const auto document = connection_pool->get_document();
   if(!document)
-    return 0;
+    return nullptr;
 
   const auto contents = document->get_contents();
   //std::cout << "debug: " << G_STRFUNC << ": returning: " << std::endl << "  " << contents << std::endl;
@@ -1001,33 +1019,4 @@ void ConnectionPool::set_fake_connection()
   set_password("glom_fake_password");
 }
 
-bool ConnectionPool::update_meta_store_for_table_names()
-{
-  try
-  {
-    //update_meta_store_table_names() has been known to throw an exception.
-    //Glom is mostly unusable when it fails, but that's still better than a crash.
-    //std::cout << G_STRFUNC << ": Before update_meta_store_table_name()" << std::endl;
-    const auto test = m_refGdaConnection->update_meta_store_table_names(m_backend->get_public_schema_name());
-    if(!test && !m_fake_connection)
-    {
-      std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed without an exception." << std::endl;
-      return false;
-    }
-  }
-  catch(const Glib::Error& ex)
-  {
-    //If the connection was not opened, because it is a fake connection,
-    //then we should not be surprised that this fails,
-    //and a warning will only be useful later when get_meta_store_data() fails when used in get_table_names_from_database().
-    if(!m_fake_connection)
-    {
-      std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed: " << ex.what() << std::endl;
-      return false;
-    }
-  }
-
-  return true;
-}
-
 } //namespace Glom
