@@ -243,7 +243,7 @@ public:
    * @param network_shared Whether the database (and document) should be available to other users over the network,
    * if possible.
    */
-  virtual bool set_network_shared(const SlotProgress& slot_progress, bool network_shared = true);
+  bool set_network_shared(const SlotProgress& slot_progress, bool network_shared = true);
 
   /** Add a field to the database.
    * The caller should then update the document's list of fields,
@@ -283,8 +283,6 @@ public:
    */
   bool change_columns(const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& fields) noexcept;
 
-  bool update_meta_store_for_table_names();
-
   /** Specify a callback that the ConnectionPool can call to get a pointer to the document.
    * This callback avoids Connection having to link to AppWindow,
    * and avoids us worrying about whether a previously-set document (via a set_document() method) is still valid.
