@@ -771,7 +771,6 @@ bool MySQL::create_text_file(const std::string& file_uri, const std::string& con
   Glib::RefPtr<Gio::FileOutputStream> stream;
 
   //Create the file if it does not already exist:
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     if(file->query_exists())
@@ -801,13 +800,6 @@ bool MySQL::create_text_file(const std::string& file_uri, const std::string& con
   }
   catch(const Gio::Error& ex)
   {
-#else
-  std::shared_ptr<Gio::Error> error;
-  stream.create(error);
-  if(error.get())
-  {
-    const auto ex = *error.get();
-#endif
     // If the operation was not successful, print the error and abort
     std::cerr << G_STRFUNC << ": ConnectionPool::create_text_file(): exception while creating file." << std::endl
       << "  file uri:" << file_uri << std::endl
@@ -822,7 +814,6 @@ bool MySQL::create_text_file(const std::string& file_uri, const std::string& con
 
   gssize bytes_written = 0;
   const auto contents_size = contents.size();
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     //Write the data to the output uri
@@ -830,12 +821,6 @@ bool MySQL::create_text_file(const std::string& file_uri, const std::string& con
   }
   catch(const Gio::Error& ex)
   {
-#else
-  bytes_written = stream->write(contents.data(), contents_size, error);
-  if(error.get())
-  {
-    auto ex = *error.get();
-#endif
     // If the operation was not successful, print the error and abort
     std::cerr << G_STRFUNC << ": ConnectionPool::create_text_file(): exception while writing to file." << std::endl
       << "  file uri:" << file_uri << std::endl
