@@ -73,8 +73,7 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
   const auto default_database = "template1";
   //const auto actual_database = (!database.empty()) ? database : default_database;;
   const auto cnc_string_main = "HOST=" + DbUtils::gda_cnc_string_encode(m_host)
-   + ";PORT=" + DbUtils::gda_cnc_string_encode(port)
-   + ";CONNECT_TIMEOUT=10"; //10 seconds timeout, instead of indefinite.
+   + ";PORT=" + DbUtils::gda_cnc_string_encode(port);
   const auto cnc_string = cnc_string_main + ";DB_NAME=" + DbUtils::gda_cnc_string_encode(database);
 
   Glib::RefPtr<Gnome::Gda::Connection> connection;
@@ -874,7 +873,6 @@ bool Postgres::create_text_file(const std::string& file_uri, const std::string&
   Glib::RefPtr<Gio::FileOutputStream> stream;
 
   //Create the file if it does not already exist:
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     if(file->query_exists())
@@ -904,13 +902,6 @@ bool Postgres::create_text_file(const std::string& file_uri, const std::string&
   }
   catch(const Gio::Error& ex)
   {
-#else
-  std::shared_ptr<Gio::Error> error;
-  stream.create(error);
-  if(error.get())
-  {
-    const auto ex = *error.get();
-#endif
     // If the operation was not successful, print the error and abort
     std::cerr << G_STRFUNC << ": ConnectionPool::create_text_file(): exception while creating file." << std::endl
       << "  file uri:" << file_uri << std::endl
@@ -925,7 +916,6 @@ bool Postgres::create_text_file(const std::string& file_uri, const std::string&
 
   gssize bytes_written = 0;
   const auto contents_size = contents.size();
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     //Write the data to the output uri
@@ -933,12 +923,6 @@ bool Postgres::create_text_file(const std::string& file_uri, const std::string&
   }
   catch(const Gio::Error& ex)
   {
-#else
-  bytes_written = stream->write(contents.data(), contents_size, error);
-  if(error.get())
-  {
-    auto ex = *error.get();
-#endif
     // If the operation was not successful, print the error and abort
     std::cerr << G_STRFUNC << ": ConnectionPool::create_text_file(): exception while writing to file." << std::endl
       << "  file uri:" << file_uri << std::endl
