@@ -166,18 +166,7 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   if(file_exists_uri(dbdir_uri))
     return InitErrors::DIRECTORY_ALREADY_EXISTS;
 
-  std::string dbdir;
-  try
-  {
-    dbdir = Glib::filename_from_uri(dbdir_uri);
-  }
-  catch(const Glib::ConvertError& ex)
-  {
-    std::cerr << G_STRFUNC << "Glib::filename_from_uri() failed: " << ex.what() << std::endl;
-
-    return InitErrors::OTHER;
-  }
-
+  const auto dbdir = Glib::filename_from_uri(dbdir_uri);
   //std::cout << "debug: dbdir=" << dbdir << std::endl;
   g_assert(!dbdir.empty());
 
@@ -220,15 +209,8 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
 
   // Make sure to use double quotes for the executable path, because the
   // CreateProcess() API used on Windows does not support single quotes.
-  // We set the default locale, with --locale, to avoid the database's initial locale
-  // from being based on the current environment, because we want the database to be
-  // as portable as possible.
-  // See http://www.postgresql.org/docs/current/static/app-initdb.html
-  const std::string command_initdb = get_path_to_postgres_executable("initdb") +
-    " -D " + Glib::shell_quote(dbdir_data) +
-    " -U " + initial_username +
-    " --pwfile=" + Glib::shell_quote(temp_pwfile) +
-    " --locale=C";
+  const std::string command_initdb = get_path_to_postgres_executable("initdb") + " -D " + Glib::shell_quote(dbdir_data) +
+                                        " -U " + initial_username + " --pwfile=" + Glib::shell_quote(temp_pwfile);
 
   //Note that --pwfile takes the password from the first line of a file. It's an alternative to supplying it when prompted on stdin.
   const auto result = Glom::Spawn::execute_command_line_and_wait(command_initdb, slot_progress);
@@ -265,18 +247,7 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
     return StartupErrors::FAILED_NO_MAIN_DIRECTORY;
   }
 
-  std::string dbdir;
-  try
-  {
-    dbdir = Glib::filename_from_uri(dbdir_uri);
-  }
-  catch(const Glib::ConvertError& ex)
-  {
-    std::cerr << G_STRFUNC << "Glib::filename_from_uri() failed: " << ex.what() << std::endl;
-
-    return StartupErrors::FAILED_UNKNOWN_REASON;
-  }
-
+  const auto dbdir = Glib::filename_from_uri(dbdir_uri);
   g_assert(!dbdir.empty());
 
   const auto dbdir_data = Glib::build_filename(dbdir, FILENAME_DATA);
@@ -403,19 +374,7 @@ bool PostgresSelfHosted::cleanup(const SlotProgress& slot_progress)
     return true; //Don't try to stop it if we have not started it.
 
   const auto dbdir_uri = m_database_directory_uri;
-
-  std::string dbdir;
-  try
-  {
-    dbdir = Glib::filename_from_uri(dbdir_uri);
-  }
-  catch(const Glib::ConvertError& ex)
-  {
-    std::cerr << G_STRFUNC << "Glib::filename_from_uri() failed: " << ex.what() << std::endl;
-
-    return false;
-  }
-
+  const auto dbdir = Glib::filename_from_uri(dbdir_uri);
   g_assert(!dbdir.empty());
 
   const auto dbdir_data = Glib::build_filename(dbdir, FILENAME_DATA);
@@ -469,18 +428,7 @@ bool PostgresSelfHosted::set_network_shared(const SlotProgress& /* slot_progress
   m_network_shared = network_shared;
 
   const auto dbdir_uri = m_database_directory_uri;
-
-  std::string dbdir;
-  try
-  {
-    dbdir = Glib::filename_from_uri(dbdir_uri);
-  }
-  catch(const Glib::ConvertError& ex)
-  {
-    std::cerr << G_STRFUNC << "Glib::filename_from_uri() failed: " << ex.what() << std::endl;
-
-    return false;
-  }
+  const auto dbdir = Glib::filename_from_uri(dbdir_uri);
 
   const std::string dbdir_uri_config = dbdir_uri + "/config";
   const char* default_conf_contents = nullptr;
@@ -560,7 +508,7 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresSelfHosted::connect(const Glib::ust
       }
       else
       {
-        throw ex;
+        throw;
       }
     }
 
