@@ -139,7 +139,7 @@ static const FieldTypes* get_field_types()
 {
   auto connection_pool = ConnectionPool::get_instance();
   if(!connection_pool)
-    return 0;
+    return nullptr;
 
   return connection_pool->get_field_types();
 }
@@ -428,8 +428,6 @@ Glib::ustring Field::sql_find(const Gnome::Gda::Value& value, const Glib::RefPtr
         return "''"; //We want to ignore the concept of NULL strings, and deal only with empty strings.
       else
         return ("%" + value.to_string() + "%"); //TODO: Escape it before adding "%", but then prevent SqlBuilder from re-escaping it.
-        
-      break;
     }
     case(glom_field_type::DATE):
     case(glom_field_type::TIME):
@@ -438,7 +436,6 @@ Glib::ustring Field::sql_find(const Gnome::Gda::Value& value, const Glib::RefPtr
     default:
     {
       return sql(value, connection);
-      break;
     }
   }
 }
@@ -463,11 +460,8 @@ Gnome::Gda::SqlOperatorType Field::sql_find_operator() const
     default:
     {
       return Gnome::Gda::SQL_OPERATOR_TYPE_EQ;
-      break;
     }
   }
-
-  return Gnome::Gda::SQL_OPERATOR_TYPE_EQ;
 }
 
 
