@@ -343,8 +343,7 @@ class numpunct_thousands_separator: public std::numpunct<char>
 
 class numpunct_no_thousands_separator: public std::numpunct<char>
 {
-  //Override
-  std::string do_grouping() const
+  std::string do_grouping() const override
   {
     return "";
   };
@@ -495,13 +494,9 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
     const auto number = get_double_for_gda_value_numeric(value);
 
     //Get the locale-specific text representation, in the required format:
-    //TODO: Use std::to_string(), but with the correct locale.
     std::stringstream another_stream;
     another_stream.imbue(locale); //Tell it to parse stuff as per this locale.
 
-    constexpr auto precision = std::numeric_limits<decltype(number)>::max_digits10;
-    another_stream << std::setprecision(precision);
-
     //Numeric formatting:
     if(!iso_format)
     {
