@@ -39,15 +39,17 @@ public:
 
   LayoutItem_Text();
   LayoutItem_Text(const LayoutItem_Text& src);
+  LayoutItem_Text(LayoutItem_Text&& src) = delete;
   LayoutItem_Text& operator=(const LayoutItem_Text& src);
+  LayoutItem_Text& operator=(LayoutItem_Text&& src) = delete;
   virtual ~LayoutItem_Text();
 
-  virtual LayoutItem* clone() const;
+  LayoutItem* clone() const override;
 
   bool operator==(const LayoutItem_Text& src) const;
 
-  virtual Glib::ustring get_part_type_name() const;
-  virtual Glib::ustring get_report_part_id() const;
+  Glib::ustring get_part_type_name() const override;
+  Glib::ustring get_report_part_id() const override;
 
   /** Get the text that will be shown on each record.
    */
@@ -62,7 +64,7 @@ public:
    */
   void set_text_original(const Glib::ustring& text);
 
-  sharedptr<StaticText> m_text; //Reuse the title concept of the TranslatableItem base class to give us translatable text.
+  std::shared_ptr<StaticText> m_text; //Reuse the title concept of the TranslatableItem base class to give us translatable text.
 };
 
 } //namespace Glom
