@@ -34,13 +34,15 @@ public:
 
   LayoutItem_Summary();
   LayoutItem_Summary(const LayoutItem_Summary& src);
+  LayoutItem_Summary(const LayoutItem_Summary&& src) = delete;
   LayoutItem_Summary& operator=(const LayoutItem_Summary& src);
+  LayoutItem_Summary& operator=(LayoutItem_Summary&& src) = delete;
   virtual ~LayoutItem_Summary();
 
-  virtual LayoutItem* clone() const;
+  LayoutItem* clone() const override;
 
-  virtual Glib::ustring get_part_type_name() const;
-  virtual Glib::ustring get_report_part_id() const;
+  Glib::ustring get_part_type_name() const override;
+  Glib::ustring get_report_part_id() const override;
 };
 
 } //namespace Glom
