@@ -165,7 +165,15 @@ glom_pygda_value_from_pyobject(GValue* boxed, const boost::python::object& input
   //std::cout << "DEBUG Dates not supported." << std::endl;
 #endif
 
-    std::cerr << G_STRFUNC << ": Unhandled python type." << std::endl;
+    PyObject* as_string = PyObject_Repr(input_c);
+    boost::python::extract<std::string> extractor_string(as_string);
+    const std::string str_as_string = extractor_string;
+    Py_XDECREF(as_string);
+
+    std::cerr << G_STRFUNC << ": Unhandled python type: object as string:" <<
+      str_as_string << std::endl;
+    std::cerr << G_STRFUNC << ": PY_MAJOR_VERSION=" << PY_MAJOR_VERSION << 
+      ", PY_VERSION_HEX=" << std::hex << PY_VERSION_HEX << std::endl;
     return false; /* failed. */
 }
 
@@ -242,8 +250,6 @@ boost::python::object glom_pygda_value_as_boost_pyobject(const Glib::ValueBase&
         ret = boost::python::object(gda_numeric_get_double((GdaNumeric*)val));
     } else if(value_type == G_TYPE_FLOAT) {
         ret = boost::python::object(g_value_get_float(boxed));
-    } else if(value_type == GDA_TYPE_SHORT) {
-        ret = boost::python::object(gda_value_get_short(boxed));
     } else if(value_type == G_TYPE_STRING) {
         const auto val = g_value_get_string(boxed);
         ret = boost::python::object(val);
@@ -274,6 +280,7 @@ boost::python::object glom_pygda_value_as_boost_pyobject(const Glib::ValueBase&
         ret = boost::python::object();
     } else {
       std::cerr << G_STRFUNC << ": Glom: G_VALUE_TYPE() returned unknown type: " << value_type << std::endl;
+      std::cerr << G_STRFUNC << "  type name: " << g_type_name(value_type) << std::endl;
     }
 
     return ret;
