@@ -50,7 +50,7 @@ void set_node_attribute_value(xmlpp::Element* node, const Glib::ustring& strAttr
 {
   if(node)
   {
-    auto attribute = node->get_attribute(strAttributeName);
+    auto attribute = dynamic_cast<xmlpp::AttributeNode*>(node->get_attribute(strAttributeName));
     if(attribute)
       attribute->set_value(strValue);
     else
@@ -61,9 +61,15 @@ void set_node_attribute_value(xmlpp::Element* node, const Glib::ustring& strAttr
   }
 }
 
-xmlpp::Element* get_node_child_named(const xmlpp::Element* node, const Glib::ustring& strName)
+xmlpp::Element* get_node_child_named(xmlpp::Element* node, const Glib::ustring& strName)
 {
-  xmlpp::Element* nodeResult = nullptr;
+  auto result = get_node_child_named(const_cast<const xmlpp::Element*>(node), strName);
+  return const_cast<xmlpp::Element*>(result);
+}
+
+const xmlpp::Element* get_node_child_named(const xmlpp::Element* node, const Glib::ustring& strName)
+{
+  const xmlpp::Element* nodeResult = nullptr;
 
   if(node)
   { 
@@ -74,7 +80,7 @@ xmlpp::Element* get_node_child_named(const xmlpp::Element* node, const Glib::ust
     //as well as Elements with the name "text".
     for(const auto& item : list)
     {
-      nodeResult = dynamic_cast<xmlpp::Element*>(item);  
+      nodeResult = dynamic_cast<const xmlpp::Element*>(item);
       if(nodeResult)
         return nodeResult;
     }                       
@@ -88,7 +94,7 @@ xmlpp::Element* get_node_child_named_with_add(xmlpp::Element* node, const Glib::
   auto nodeResult = get_node_child_named(node, strName);
 
   if(!nodeResult)
-    nodeResult = node->add_child(strName);
+    nodeResult = node->add_child_element(strName);
 
   return nodeResult;
 }
@@ -223,7 +229,7 @@ void set_node_text_child_as_value(xmlpp::Element* node, const Gnome::Gda::Value&
     return;
 
   const auto value_as_text = Field::to_file_format(value, field_type);
-  node->set_child_text( Utils::string_clean_for_xml(value_as_text) );
+  node->set_first_child_text( Utils::string_clean_for_xml(value_as_text) );
 
   if(field_type == Field::glom_field_type::IMAGE)
   {
@@ -245,7 +251,7 @@ Gnome::Gda::Value get_node_attribute_value_as_value(const xmlpp::Element* node,
 
 Gnome::Gda::Value get_node_text_child_as_value(const xmlpp::Element* node, Field::glom_field_type field_type)
 {
-  const auto text_child = node->get_child_text();
+  const auto text_child = node->get_first_child_text();
   if(!text_child)
     return Gnome::Gda::Value();
 
@@ -270,7 +276,7 @@ Glib::ustring get_child_text_node(const xmlpp::Element* node, const Glib::ustrin
   const auto child = get_node_child_named(node, child_node_name);
   if(child)
   {
-     const auto text_child = child->get_child_text();
+     const auto text_child = child->get_first_child_text();
      if(text_child)
        return text_child->get_content();
   }
@@ -286,12 +292,12 @@ void set_child_text_node(xmlpp::Element* node, const Glib::ustring& child_node_n
     if(text.empty())
       return; //Keep the document smaller by avoiding empty nodes.
 
-    child = node->add_child(child_node_name);
+    child = node->add_child_element(child_node_name);
   }
 
   const auto text_used = Utils::string_clean_for_xml(text);
 
-  auto text_child = child->get_child_text();
+  auto text_child = child->get_first_child_text();
   if(!text_child)
     child->add_child_text(text_used);
   else
