@@ -51,19 +51,19 @@ public:
   bool init_db_details(const FoundSet& found_set, const Glib::ustring& layout_platform);
 
   //Fill the existing layout with data from the database:
-  virtual bool refresh_data_from_database_with_where_clause(const FoundSet& found_set);
+  bool refresh_data_from_database_with_where_clause(const FoundSet& found_set);
 
   virtual void print_layout(); //A test, for now.
 
   ///Get the existing where clause, previously supplied to init_db_details().
   FoundSet get_found_set() const;
 
-  virtual Gnome::Gda::SqlExpr get_find_where_clause() const;
+  Gnome::Gda::SqlExpr get_find_where_clause() const;
 
-  virtual void set_unstored_data(bool bVal);
-  virtual bool get_unstored_data() const;
+  void set_unstored_data(bool bVal);
+  bool get_unstored_data() const;
 
-  virtual bool confirm_discard_unstored_data() const;
+  bool confirm_discard_unstored_data() const;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void show_layout_dialog();
@@ -95,7 +95,7 @@ protected:
   virtual void create_layout();
 
   ///Fill the existing layout with data from the database.
-  virtual bool fill_from_database() override;
+  bool fill_from_database() override;
 
   virtual type_vecConstLayoutFields get_fields_to_show() const;
 
