@@ -43,37 +43,37 @@ public:
   /**
    * @param portal: The full portal details
    */
-  virtual bool init_db_details(const std::shared_ptr<const LayoutItem_Portal>& portal, bool show_title = true);
+  bool init_db_details(const std::shared_ptr<const LayoutItem_Portal>& portal, bool show_title = true) override;
 
   /** Use this if no portal is yet defined, so the user can use the context menu to define a portal.
    */
-  virtual bool init_db_details(const Glib::ustring& parent_table, bool show_title = true);
+  bool init_db_details(const Glib::ustring& parent_table, bool show_title = true) override;
 
 private:
-  virtual bool fill_from_database() override;
-  virtual type_vecConstLayoutFields get_fields_to_show() const override;
-  virtual void create_layout() override;
+  bool fill_from_database() override;
+  type_vecConstLayoutFields get_fields_to_show() const override;
+  void create_layout() override;
     
     
   //Implementations of pure virtual methods from Base_DB_Table_Data:
-  virtual void set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value);
+  void set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value) override;
     
 
   void on_record_added(const Gnome::Gda::Value& primary_key_value, const Gtk::TreeModel::iterator& row) override; //Not a signal handler.
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual void on_dialog_layout_hide() override;
+  void on_dialog_layout_hide() override;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  virtual void enable_buttons();
+  void enable_buttons();
     
   //Implementations of pure virtual methods from Base_DB_Table_Data:
-  virtual Gnome::Gda::Value get_primary_key_value_selected() const;
-  virtual Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row) const;
+  Gnome::Gda::Value get_primary_key_value_selected() const override;
+  Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row) const override;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual Dialog_Layout* create_layout_dialog() const override;
-  virtual void prepare_layout_dialog(Dialog_Layout* dialog) override;
+  Dialog_Layout* create_layout_dialog() const override;
+  void prepare_layout_dialog(Dialog_Layout* dialog) override;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   Glib::ustring on_calendar_details(guint year, guint month, guint day);
