@@ -224,7 +224,7 @@ void Box_Data_Details::create_layout()
 
     for(const auto& item : layout_groups)
     {
-      m_FlowTable.add_layout_group_or_derived(item, false /* no indent at this top level */);
+      m_FlowTable.add_layout_group(item, false /* no indent at this top level */);
     }
 
     m_FlowTable.align_child_group_labels();
@@ -392,8 +392,6 @@ bool Box_Data_Details::fill_from_database()
       }
     } //if(!fieldsToGet.empty())
 
-    //fill_related();
-
     set_unstored_data(false);
   }
 
@@ -509,7 +507,7 @@ Gnome::Gda::Value Box_Data_Details::get_primary_key_value_selected() const
 
 void Box_Data_Details::recalculate_fields_for_related_records(const Glib::ustring& relationship_name)
 {
-  m_FieldsCalculationInProgress.clear();
+  clear_fields_calculation_in_progress();
 
   //Check all fields in the parent table:
   const auto primary_key_value = get_primary_key_value_selected();
@@ -536,7 +534,7 @@ void Box_Data_Details::recalculate_fields_for_related_records(const Glib::ustrin
     }
   }
 
-   m_FieldsCalculationInProgress.clear();
+   clear_fields_calculation_in_progress();
 }
 
 void Box_Data_Details::on_related_record_added(Gnome::Gda::Value /* strKeyValue */, Glib::ustring /* strFromKeyName */)
