@@ -39,8 +39,6 @@ public:
 
   bool get_showing_multiple_records() const;
 
-  void set_read_only(bool read_only = true);
-
   //For instance, change "Open" to "Select" when used to select an ID.
   void set_open_button_title(const Glib::ustring& title);
 
@@ -60,11 +58,8 @@ protected:
   //virtual Document::type_list_layout_groups create_layout_get_layout() ; //overriden in Box_Data_ManyRecords_Related.
   void create_layout_add_group(const std::shared_ptr<LayoutGroup>& layout_group);
 
-  virtual void print_layout();
-  virtual void print_layout_group(xmlpp::Element* node_parent, const std::shared_ptr<const LayoutGroup>& group);
-
-  bool m_read_only;
-
+  void print_layout() override;
+  void print_layout_group(xmlpp::Element* node_parent, const std::shared_ptr<const LayoutGroup>& group);
 
   type_signal_user_requested_details m_signal_user_requested_details;
   type_signal_record_selection_changed m_signal_record_selection_changed;
