@@ -44,17 +44,17 @@ public:
   explicit CheckButton(const Glib::ustring& title = Glib::ustring());
   virtual ~CheckButton();
 
-  virtual void set_value(const Gnome::Gda::Value& value);
-  virtual Gnome::Gda::Value get_value() const;    
+  void set_value(const Gnome::Gda::Value& value) override;
+  Gnome::Gda::Value get_value() const override;    
 
 private:
   void init();
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual bool on_button_press_event(GdkEventButton *event) override;
+  bool on_button_press_event(GdkEventButton *event) override;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  virtual AppWindow* get_appwindow() const;
+  AppWindow* get_appwindow() const override;
 };
 
 } //namespace DataWidetChildren
