@@ -54,32 +54,28 @@ public:
 
   /** Set the text from a Gnome::Gda::Value.
    */
-  virtual void set_value(const Gnome::Gda::Value& value);
+  void set_value(const Gnome::Gda::Value& value) override;
 
-  virtual Gnome::Gda::Value get_value() const;
+  Gnome::Gda::Value get_value() const override;
 
   typedef Gtk::TextView type_text_view;
   
   type_text_view* get_textview();
   
-  void set_read_only(bool read_only = true);
+  void set_read_only(bool read_only = true) override;
 
 private:
   void init();
 
-  //Overrides of default signal handlers:
-  void on_buffer_changed();
-  //virtual void on_activate() override; //From Gtk::Entry.
   bool on_textview_focus_out_event(GdkEventFocus* focus_event);
-  //virtual void on_insert_text(const Glib::ustring& text, int* position); //From Gtk::Editable
 
-  virtual void check_for_change();
+  void check_for_change();
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual bool on_button_press_event(GdkEventButton *event) override;
+  bool on_button_press_event(GdkEventButton *event) override;
 #endif
 
-  virtual AppWindow* get_appwindow() const;
+  AppWindow* get_appwindow() const override;
 
   Glib::ustring m_old_text;
   Field::glom_field_type m_glom_type; //Store the type so we can validate the text accordingly.
