@@ -56,7 +56,7 @@ public:
   virtual ~DbAddDel();
 
   virtual void set_allow_user_actions(bool bVal = true);
-  virtual bool get_allow_user_actions() const;
+  bool get_allow_user_actions() const;
 
   virtual void set_allow_add(bool val = true);
   virtual void set_allow_delete(bool val = true);
@@ -174,13 +174,6 @@ public:
 
   std::shared_ptr<const LayoutItem_Field> get_column_field(guint column_index) const;
 
-  typedef std::vector<Glib::ustring> type_vec_strings;
-
-  /** Retrieves the column order, even after they have been reordered by the user.
-   * @result a vector of column_id. These column_ids were provided in the call to add_column().
-   */
-  type_vec_strings get_columns_order() const;
-
   void remove_all_columns();
 
   /// For popup cells.
@@ -194,7 +187,7 @@ public:
   Gtk::TreeModel::iterator get_row(const Gnome::Gda::Value& key);
 
   void finish_editing(); //Closes active edit controls and commits the data to the cell.
-  //virtual void reactivate(); //Sheet doesn't seem to update unless a cell is active.
+  //void reactivate(); //Sheet doesn't seem to update unless a cell is active.
   void set_prevent_user_signals(bool bVal = true);
 
   //TODO_refactor: make private.
@@ -277,16 +270,16 @@ private:
   void set_value(const Gtk::TreeModel::iterator& iter, const std::shared_ptr<const LayoutItem_Field>& layout_item, const Gnome::Gda::Value& value, bool set_specified_field_layout);
 
   //Overrides of Base_DB/Base_DB_Table methods:
-  virtual void set_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value) override;
-  virtual void set_entered_field_data(const Gtk::TreeModel::iterator& row, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value) override;
-  virtual Gnome::Gda::Value get_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field) const override;
-  virtual Gtk::TreeModel::iterator get_row_selected();
+  void set_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value) override;
+  void set_entered_field_data(const Gtk::TreeModel::iterator& row, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value) override;
+  Gnome::Gda::Value get_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field) const override;
+  Gtk::TreeModel::iterator get_row_selected() override;
 
   //Implementations of pure virtual methods from Base_DB_Table_Data:
-  virtual std::shared_ptr<Field> get_field_primary_key() const;
-  virtual Gnome::Gda::Value get_primary_key_value_selected() const;
-  virtual void set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value);
-  virtual Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row) const;
+  std::shared_ptr<Field> get_field_primary_key() const override;
+  Gnome::Gda::Value get_primary_key_value_selected() const override;
+  void set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value) override;
+  Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row) const override;
 
   Gtk::CellRenderer* construct_specified_columns_cellrenderer(const std::shared_ptr<LayoutItem>& layout_item, int model_column_index, int data_model_column_index);
 
@@ -328,7 +321,6 @@ private:
   void on_treeview_cell_edited_bool(const Glib::ustring& path_string, int model_column_index, int data_model_column_index);
   void on_idle_treeview_cell_edited_revert(const Gtk::TreeModel::Row& row, guint model_column_index);
 
-  bool on_treeview_column_drop(Gtk::TreeView* treeview, Gtk::TreeViewColumn* column, Gtk::TreeViewColumn* prev_column, Gtk::TreeViewColumn* next_column);
   void on_treeview_columns_changed();
 
   bool on_button_press_event_Popup(GdkEventButton* button_event);
@@ -347,7 +339,6 @@ private:
   void on_MenuPopup_activate_layout();
 #endif
 
-  bool on_treeview_columnheader_button_press_event(GdkEventButton* button_event);
   void on_treeview_column_clicked(int model_column_index);
   //void on_treeview_column_resized(int model_column_index, DbTreeViewColumnGlom* view_column);
   void on_idle_row_edit();
@@ -474,7 +465,7 @@ private:
   class InnerIgnore
   {
   public:
-    InnerIgnore(DbAddDel* pOuter);
+    explicit InnerIgnore(DbAddDel* pOuter);
     ~InnerIgnore();
 
   private:
