@@ -112,53 +112,46 @@ void FlowTableWithFields::add_layout_item(const std::shared_ptr<LayoutItem>& ite
   }
   else
   {
-    auto group = std::dynamic_pointer_cast<LayoutGroup>(item);
-    if(group)
+    std::shared_ptr<LayoutItem_Portal> portal = std::dynamic_pointer_cast<LayoutItem_Portal>(item);
+    if(portal)
     {
-      add_layout_group_or_derived(group);
+      add_layout_portal(portal);
     }
     else
     {
-      auto layout_button = std::dynamic_pointer_cast<LayoutItem_Button>(item);
-      if(layout_button)
-        add_button(layout_button, m_table_name);
+      std::shared_ptr<LayoutItem_Notebook> notebook = std::dynamic_pointer_cast<LayoutItem_Notebook>(item);
+      if(notebook)
+      {
+        add_layout_notebook(notebook);
+      }
       else
       {
-        auto layout_textobject = std::dynamic_pointer_cast<LayoutItem_Text>(item);
-        if(layout_textobject)
-          add_textobject(layout_textobject, m_table_name);
+        std::shared_ptr<LayoutGroup> group = std::dynamic_pointer_cast<LayoutGroup>(item);
+        if(group)
+          add_layout_group(group);
         else
         {
-          auto layout_imageobject = std::dynamic_pointer_cast<LayoutItem_Image>(item);
-          if(layout_imageobject)
-            add_imageobject(layout_imageobject, m_table_name);
+          std::shared_ptr<LayoutItem_Button> layout_button = std::dynamic_pointer_cast<LayoutItem_Button>(item);
+          if(layout_button)
+            add_button(layout_button, m_table_name);
+          else
+          {
+            std::shared_ptr<LayoutItem_Text> layout_textobject = std::dynamic_pointer_cast<LayoutItem_Text>(item);
+            if(layout_textobject)
+              add_textobject(layout_textobject, m_table_name);
+            else
+            {
+              std::shared_ptr<LayoutItem_Image> layout_imageobject = std::dynamic_pointer_cast<LayoutItem_Image>(item);
+              if(layout_imageobject)
+                add_imageobject(layout_imageobject, m_table_name);
+            }
+          }
         }
       }
     }
   }
 }
 
-void FlowTableWithFields::add_layout_group_or_derived(const std::shared_ptr<LayoutGroup>& group, bool with_indent)
-{
-  auto portal = std::dynamic_pointer_cast<LayoutItem_Portal>(group);
-  if(portal)
-  {
-    add_layout_portal(portal);
-  }
-  else
-  {
-    auto notebook = std::dynamic_pointer_cast<LayoutItem_Notebook>(group);
-    if(notebook)
-    {
-      add_layout_notebook(notebook);
-    }
-    else
-    {
-      add_layout_group(group, with_indent);
-    }
-  }
-}
-          
 void FlowTableWithFields::add_layout_group(const std::shared_ptr<LayoutGroup>& group, bool with_indent)
 {
   if(!group)
@@ -254,7 +247,7 @@ void FlowTableWithFields::add_layout_group(const std::shared_ptr<LayoutGroup>& g
 Box_Data_List_Related* FlowTableWithFields::create_related(const std::shared_ptr<LayoutItem_Portal>& portal, bool show_title)
 {
   if(!portal)
-    return 0;
+    return nullptr;
 
   auto pDocument = static_cast<Document*>(get_document());
   if(pDocument)
@@ -288,13 +281,13 @@ Box_Data_List_Related* FlowTableWithFields::create_related(const std::shared_ptr
     return portal_box;
   }
 
-  return 0;
+  return nullptr;
 }
 
 Box_Data_Calendar_Related* FlowTableWithFields::create_related_calendar(const std::shared_ptr<LayoutItem_CalendarPortal>& portal, bool show_title)
 {
   if(!portal)
-    return 0;
+    return nullptr;
 
   auto pDocument = static_cast<Document*>(get_document());
   if(pDocument)
@@ -328,7 +321,7 @@ Box_Data_Calendar_Related* FlowTableWithFields::create_related_calendar(const st
     return portal_box;
   }
 
-  return 0;
+  return nullptr;
 }
 
 void FlowTableWithFields::add_layout_portal(const std::shared_ptr<LayoutItem_Portal>& portal)
@@ -939,11 +932,6 @@ FlowTableWithFields::type_list_widgets FlowTableWithFields::get_field(const std:
   return result;
 }
 
-void FlowTableWithFields::change_group(const Glib::ustring& /* id */, const Glib::ustring& /*new_group */)
-{
-  //TODO.
-}
-
 void FlowTableWithFields::remove_all()
 {
   FlowTable::remove_all();
@@ -1022,17 +1010,17 @@ void FlowTableWithFields::on_script_button_clicked(const std::shared_ptr< Layout
   m_signal_script_button_clicked.emit(layout_item);
 }
 
-void FlowTableWithFields::on_entry_edited(const Gnome::Gda::Value& value, const std::shared_ptr<const LayoutItem_Field> field)
+void FlowTableWithFields::on_entry_edited(const Gnome::Gda::Value& value, const std::shared_ptr<const LayoutItem_Field>& field)
 {
   m_signal_field_edited.emit(field, value);
 }
 
-void FlowTableWithFields::on_entry_choices_changed(const std::shared_ptr<const LayoutItem_Field> field)
+void FlowTableWithFields::on_entry_choices_changed(const std::shared_ptr<const LayoutItem_Field>& field)
 {
   m_signal_field_choices_changed.emit(field);
 }
 
-void FlowTableWithFields::on_entry_open_details_requested(const Gnome::Gda::Value& value, const std::shared_ptr<const LayoutItem_Field> field)
+void FlowTableWithFields::on_entry_open_details_requested(const Gnome::Gda::Value& value, const std::shared_ptr<const LayoutItem_Field>& field)
 {
   m_signal_field_open_details_requested.emit(field, value);
 }
