@@ -61,11 +61,11 @@ class FlowTableWithFields
     public View_Composite_Glom
 {
 public:
-  FlowTableWithFields(const Glib::ustring& table_name = Glib::ustring());
+  explicit FlowTableWithFields(const Glib::ustring& table_name = Glib::ustring());
   virtual ~FlowTableWithFields();
 
   ///The table name is needed to discover details of relationships.
-  virtual void set_table(const Glib::ustring& table_name);
+  void set_table(const Glib::ustring& table_name);
 
   /** Prevent any attempts to change actual records,
    * if the widget is just being used to enter find critera,
@@ -86,10 +86,10 @@ public:
 
   void add_layout_item(const std::shared_ptr<LayoutItem>& item);
 
-    /**
+  /**
    * @param with_indent Pass true for top-level groups, to avoid wasting extra space with an unnecessary indent.
    */
-  void add_layout_group_or_derived(const std::shared_ptr<LayoutGroup>& group, bool with_indent = true);
+  void add_layout_group(const std::shared_ptr<LayoutGroup>& group, bool with_indent = true);
 
   void set_field_editable(const std::shared_ptr<const LayoutItem_Field>& field, bool editable = true);
 
@@ -111,11 +111,9 @@ public:
   typedef std::list<Gtk::Widget*> type_list_widgets;
   typedef std::list<const Gtk::Widget*> type_list_const_widgets;
 
-  virtual void change_group(const Glib::ustring& id, const Glib::ustring& new_group);
+  void set_design_mode(bool value = true) override;
 
-  virtual void set_design_mode(bool value = true);
-
-  virtual void remove_all();
+  void remove_all();
 
   typedef std::vector< Glib::RefPtr<Gtk::SizeGroup> > type_vec_sizegroups;
 
@@ -205,9 +203,9 @@ private:
 
   //int get_suitable_width(Field::glom_field_type field_type);
 
-  void on_entry_edited(const Gnome::Gda::Value& value, const std::shared_ptr<const LayoutItem_Field> field);
-  void on_entry_choices_changed(const std::shared_ptr<const LayoutItem_Field> field);
-  void on_entry_open_details_requested(const Gnome::Gda::Value& value, const std::shared_ptr<const LayoutItem_Field> field);
+  void on_entry_edited(const Gnome::Gda::Value& value, const std::shared_ptr<const LayoutItem_Field>& field);
+  void on_entry_choices_changed(const std::shared_ptr<const LayoutItem_Field>& field);
+  void on_entry_open_details_requested(const Gnome::Gda::Value& value, const std::shared_ptr<const LayoutItem_Field>& field);
 
   void on_script_button_clicked(const std::shared_ptr<LayoutItem_Button>& layout_item);
 
@@ -249,14 +247,6 @@ private:
   void add_imageobject(const std::shared_ptr<LayoutItem_Image>& layoutitem_image, const Glib::ustring& table_name);
 
   void add_layoutwidgetbase(LayoutWidgetBase* layout_widget);
-
-  /** Add a normal group, not a notebook or portal.
-   * See also add_layout_group_or_derived().
-   *
-   * @param with_indent Pass true for top-level groups, to avoid wasting extra space with an unnecessary indent.
-   */
-  void add_layout_group(const std::shared_ptr<LayoutGroup>& group, bool with_indent = true);
-
   void add_layout_notebook(const std::shared_ptr<LayoutItem_Notebook>& notebook);
   void add_layout_portal(const std::shared_ptr<LayoutItem_Portal>& portal);
 
@@ -289,9 +279,9 @@ private:
 
   //menu
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual void on_menu_properties_activate();
-  virtual void on_menu_delete_activate(); // override this to add a dialog box
-  virtual bool on_button_press_event(GdkEventButton *event) override;
+  void on_menu_properties_activate() override;
+  void on_menu_delete_activate() override; // override this to add a dialog box
+  bool on_button_press_event(GdkEventButton *event) override;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 };
 
