@@ -47,9 +47,7 @@ type_list_currencies get_list_of_currency_symbols()
   {
     const Glib::ustring filename = ISO_CODES_PREFIX "/share/xml/iso-codes/iso_4217.xml";
 
-#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     try
-#endif // LIBXMLCPP_EXCEPTIONS_ENABLED
     {
       xmlpp::DomParser parser;
       //parser.set_validate();
@@ -87,12 +85,10 @@ type_list_currencies get_list_of_currency_symbols()
         }
       }
     }
-#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     catch(const std::exception& ex)
     {
       std::cerr << G_STRFUNC << ": Exception while parsing iso codes (currencies): " << ex.what() << std::endl;
     }
-#endif // LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   return list_currencies;
@@ -152,9 +148,7 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
 
     const std::string filename_languages = ISO_CODES_PREFIX "/share/xml/iso-codes/iso_639.xml";
 
-#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     try
-#endif // LIBXMLCPP_EXCEPTIONS_ENABLED
     {
       xmlpp::DomParser parser;
       //parser.set_validate();
@@ -193,12 +187,10 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
         }
       }
     }
-#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     catch(const std::exception& ex)
     {
       std::cerr << G_STRFUNC << ": Exception while parsing iso codes (locales): " << ex.what() << std::endl;
     }
-#endif // LIBXMLCPP_EXCEPTIONS_ENABLED
 
     //Get the (translated) country names:
     typedef std::map<Glib::ustring, Glib::ustring> type_map_country; //ID to country name.
@@ -206,9 +198,7 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
 
     const Glib::ustring filename_countries = ISO_CODES_PREFIX "/share/xml/iso-codes/iso_3166.xml";
 
-#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     try
-#endif // LIBXMLCPP_EXCEPTIONS_ENABLED
     {
       xmlpp::DomParser parser;
       //parser.set_validate();
@@ -246,12 +236,10 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
         }
       }
     }
-#ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     catch(const std::exception& ex)
     {
       std::cerr << G_STRFUNC << ": Exception while parsing iso codes (locales): " << ex.what() << std::endl;
     }
-#endif // LIBXMLCPP_EXCEPTIONS_ENABLED
 
     //Use a map so we can easily check for duplicates.
     for(const auto& id : list_ids)
