@@ -50,18 +50,18 @@ public:
 
   void init_with_tablename(const Glib::ustring& layout, const Glib::ustring& layout_platform, Document* document, const Glib::ustring& parent_table);
 
-  virtual void update_ui(bool including_relationships_list = true);
+  void update_ui(bool including_relationships_list = true);
 
   std::shared_ptr<Relationship> get_relationship() const;
   std::shared_ptr<LayoutItem_CalendarPortal>  get_portal_layout();
 
 private:
 
-  virtual void save_to_document();
+  void save_to_document() override;
 
   //signal handlers:
-  virtual void on_button_add_field() override;
-  virtual void on_button_edit() override;
+  void on_button_add_field() override;
+  void on_button_edit() override;
  
   void on_combo_relationship_changed();
   
