@@ -21,7 +21,6 @@
 #include <glom/mode_design/layout/dialog_layout_details.h>
 #include <glom/mode_design/layout/dialog_choose_relationship.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_buttonscript.h>
-#include <glom/mode_design/layout/layout_item_dialogs/dialog_notebook.h>
 #include <glom/glade_utils.h>
 #include <glom/frame_glom.h> //For show_ok_dialog()
 //#include <libgnome/gnome-i18n.h>
@@ -950,14 +949,6 @@ void Dialog_Layout_Details::on_button_edit()
         if(layout_notebook)
         {
           Frame_Glom::show_ok_dialog(_("Notebook Tabs"), _("Add child groups to the notebook to add tabs."), *this);
-          /*
-          std::shared_ptr<LayoutItem_Notebook> chosen = offer_notebook(layout_notebook);
-          if(chosen)
-          {
-            row[m_model_items->m_columns.m_col_layout_item] = chosen;
-            m_modified = true;
-          }
-          */
         }
         else
         {
@@ -1062,30 +1053,15 @@ void Dialog_Layout_Details::save_to_document()
     for(const auto& row : m_model_items->children())
     {
       std::shared_ptr<LayoutItem> layout_item = row[m_model_items->m_columns.m_col_layout_item];
+      std::shared_ptr<LayoutGroup> layout_group = std::dynamic_pointer_cast<LayoutGroup>(layout_item);
+      std::shared_ptr<LayoutItem_Portal> layout_portal = std::dynamic_pointer_cast<LayoutItem_Portal>(layout_item);
+      if(layout_group && !layout_portal) //There may be top-level groups, but no top-level fields, because the fields must be in a group (so that they are in columns)
+      {
+        std::shared_ptr<LayoutGroup> group = std::make_shared<LayoutGroup>();
+        fill_group(row, group);
 
-      //There may be top-level groups, but no top-level fields, because the fields must be in a group (so that they are in columns)
-      auto layout_group = std::dynamic_pointer_cast<LayoutGroup>(layout_item);
-      if(!layout_group)
-        continue;
-
-      //TODO: This is very ugly:
-      auto layout_portal = std::dynamic_pointer_cast<LayoutItem_Portal>(layout_item);
-      auto layout_calendar_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(layout_item);
-      auto layout_notebook = std::dynamic_pointer_cast<LayoutItem_Notebook>(layout_item);
-      std::shared_ptr<LayoutGroup> group;
-      if(layout_portal) {
-        group = std::make_shared<LayoutItem_Portal>();
-      } else if(layout_calendar_portal) {
-        group = std::make_shared<LayoutItem_CalendarPortal>();
-      } else if(layout_notebook) {
-        group = std::make_shared<LayoutItem_Notebook>();
-      } else {
-        group = std::make_shared<LayoutGroup>();
+        list_groups.push_back(group);
       }
-
-      fill_group(row, group);
-
-      list_groups.emplace_back(group);
     }
 
     if(document)
