@@ -48,21 +48,21 @@ public:
    */
   void init_with_portal(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* document, const std::shared_ptr<const LayoutItem_Portal>& portal, const Glib::ustring& from_table, bool for_print_layout = false);
 
-  virtual void update_ui(bool including_relationships_list = true);
+  void update_ui(bool including_relationships_list = true);
 
   std::shared_ptr<Relationship> get_relationship() const;
   std::shared_ptr<LayoutItem_Portal>  get_portal_layout();
 
 protected:
 
-  virtual void save_to_document();
+  void save_to_document() override;
 
   ///@inheritdoc
-  virtual Glib::ustring get_fields_table() const;
+  Glib::ustring get_fields_table() const override;
 
   //signal handlers:
-  virtual void on_button_add_field() override;
-  virtual void on_button_edit() override;
+  void on_button_add_field() override;
+  void on_button_edit() override;
  
   void on_combo_relationship_changed();
   
