@@ -60,9 +60,6 @@ private:
   {
     return "flowtable";
   };
-
-  virtual void on_drag_begin(const Glib::RefPtr<Gdk::DragContext>& drag_context);
-  virtual void on_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&, Gtk::SelectionData& selection_data, guint, guint);
   
 private:
   enumItems m_type;
