@@ -46,13 +46,13 @@ public:
   Window_Translations(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Window_Translations();
 
-  virtual void load_from_document() override;
-  virtual void save_to_document() override;
+  void load_from_document() override;
+  void save_to_document() override;
 
 private:
 
   //Enable/disable buttons, depending on treeview selection:
-  virtual void enable_buttons();
+  void enable_buttons();
 
   //signal handlers:
   void on_button_identify();
