@@ -34,15 +34,13 @@ public:
 
   bool init_db_details(const Glib::ustring& table_name, const Glib::ustring& layout_platform);
 
-  virtual Gtk::Widget* get_default_button() override;
+  Gtk::Widget* get_default_button() override;
 
 private:
 
-  virtual bool fill_from_database() override;
-  void fill_related();
-
-  virtual void on_flowtable_field_edited(const std::shared_ptr<const LayoutItem_Field>& id, const Gnome::Gda::Value& value);
+  bool fill_from_database() override;
 
+  void on_flowtable_field_edited(const std::shared_ptr<const LayoutItem_Field>& id, const Gnome::Gda::Value& value) override;
 };
 
 } //namespace Glom
