@@ -34,12 +34,12 @@ public:
 
   virtual bool init_db_details(const Glib::ustring& table_name, const Glib::ustring& layout_platform);
 
-  virtual Gtk::Widget* get_default_button() override;
+  Gtk::Widget* get_default_button() override;
 
 private:
 
-  virtual bool fill_from_database() override;
-  virtual void create_layout();
+  bool fill_from_database() override;
+  void create_layout() override;
 
   //Member widgets:
   Gtk::Box m_HBox;
