@@ -52,7 +52,7 @@ private:
 
   //Signal handlers:
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual void save_to_document();
+  void save_to_document() override;
 
   void on_adddel_Add(const Gtk::TreeModel::iterator& row);
   void on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& rowEnd);
@@ -62,7 +62,7 @@ private:
 
   void on_show_hidden_toggled();
 
-  virtual void on_userlevel_changed(AppState::userlevels userlevel);
+  void on_userlevel_changed(AppState::userlevels userlevel) override;
       
   Gtk::CheckButton* m_pCheckButtonShowHidden;
   guint m_colTableName;
