@@ -747,9 +747,6 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
   typedef std::map<Glib::ustring, guint> type_map_layout_fields_index;
   type_map_layout_fields_index map_fields_index;
 
-  typedef std::list< std::shared_ptr<LayoutItem_Portal> > type_list_portals;
-  type_list_portals list_portals;
-
   //Get list of fields to get from the database.
   Utils::type_vecLayoutFields fieldsToGet;
   const int count = canvas_group->get_n_children();
@@ -930,8 +927,6 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
   //Do not use less than the minimum:
   rows_count = std::max(rows_count, (int)rows_count_min);
 
-  // TODO: Remove this method and/or change it to recalc the min when changing the height:
-  //CanvasLayoutItem::get_rows_count_for_portal(portal, row_height_ignored);
   const double portal_height = rows_count * portal->get_print_layout_row_height();
 
   double old_width = 0;
