@@ -152,18 +152,13 @@ public:
 
   Glib::ustring get_column_field(guint column_index) const;
 
-  typedef AddDelColumnInfo::type_vec_strings type_vec_strings;
-
-  /** Retrieves the column order, even after they have been reordered by the user.
-   * @result a vector of column_id. These column_ids were provided in the call to add_column().
-   */
-  type_vec_strings get_columns_order() const;
-
   void remove_all_columns();
   //void set_columns_count(guint count);
   //void set_column_title(guint col, const Glib::ustring& strText);
   void set_column_width(guint col, guint width);
 
+  typedef AddDelColumnInfo::type_vec_strings type_vec_strings;
+
   /// For popup cells.
   void set_column_choices(guint col, const type_vec_strings& vecStrings);
 
@@ -215,9 +210,6 @@ public:
   typedef sigc::signal<void, const Gtk::TreeModel::iterator&, guint> type_signal_user_activated;
   type_signal_user_activated signal_user_activated();
 
-  typedef sigc::signal<void> type_signal_user_reordered_columns;
-  type_signal_user_reordered_columns signal_user_reordered_columns();
-
   bool get_model_column_index(guint view_column_index, guint& model_column_index);
 
   /** Get the last row. This will generally be the placeholder row.
@@ -260,7 +252,6 @@ private:
 
   void on_treeview_cell_editing_started(Gtk::CellEditable* editable, const Glib::ustring& path, int model_column_index);
 
-  bool on_treeview_column_drop(Gtk::TreeView* treeview, Gtk::TreeViewColumn* column, Gtk::TreeViewColumn* prev_column, Gtk::TreeViewColumn* next_column);
   void on_treeview_columns_changed();
 
   bool on_button_press_event_Popup(GdkEventButton* button_event);
@@ -334,14 +325,13 @@ private:
   type_signal_user_requested_extra m_signal_user_requested_extra;
   type_signal_user_requested_add m_signal_user_requested_add;
   type_signal_user_activated m_signal_user_activated;
-  type_signal_user_reordered_columns m_signal_user_reordered_columns;
 
   //An instance of InnerIgnore remembers the ignore settings,
   //then restores them when it goes out of scope and is destroyed.
   class InnerIgnore
   {
   public:
-    InnerIgnore(AddDel* pOuter);
+    explicit InnerIgnore(AddDel* pOuter);
     ~InnerIgnore();
 
   protected:
