@@ -32,8 +32,8 @@ public:
   TreeViewColumnGlom(const Glib::ustring& title, Gtk::CellRenderer& cell);
   virtual ~TreeViewColumnGlom();
 
-  virtual Glib::ustring get_column_id() const;
-  virtual void set_column_id(const Glib::ustring& value);
+  Glib::ustring get_column_id() const;
+  void set_column_id(const Glib::ustring& value);
 
 private:
   Glib::ustring m_column_id; 
