@@ -112,13 +112,11 @@ bool CanvasItemMovable::on_button_press_event(const Glib::RefPtr<Goocanvas::Item
         m_shift_click = true;
 
       return true; // Handled.
-      break;
     }
     case 3:
     {
       m_signal_show_context.emit(event->button, event->time);
       return false; // Not fully Handled.
-      break;
     }
     default:
       break;
@@ -443,13 +441,6 @@ Glib::RefPtr<Goocanvas::Item> CanvasItemMovable::cast_to_item(const Glib::RefPtr
   return result;
 }
 
-//static:
-Glib::RefPtr<const Goocanvas::Item> CanvasItemMovable::cast_const_to_item(const Glib::RefPtr<const CanvasItemMovable>& item)
-{
-  Glib::RefPtr<CanvasItemMovable> unconst = Glib::RefPtr<CanvasItemMovable>::cast_const(item);
-  return cast_to_item(unconst);
-}
-
 void CanvasItemMovable::set_selected(bool selected)
 {
   m_selected = selected;
