@@ -37,7 +37,7 @@ public:
   virtual ~Dialog_Properties();
 
   //Add a widget (probably a container) to the top half of the dialog:
-  virtual void add(Gtk::Widget& widget);
+  void add(Gtk::Widget& widget) override;
 
   virtual void set_modified(bool modified = true);
 
@@ -51,7 +51,7 @@ protected:
   void on_button_cancel();
 
   void on_anything_changed();
-  virtual void on_adddel_user_changed(const Gtk::TreeModel::iterator& /* iter */, guint /* col */);
+  void on_adddel_user_changed(const Gtk::TreeModel::iterator& /* iter */, guint /* col */);
 
   /// Disable/enable other controls when a control is selected.
   virtual void enforce_constraints();
