@@ -53,7 +53,7 @@ const Gtk::Box* FlowTable::get_parent_hbox(const Gtk::Widget* first) const
   if(iter_find == m_list_first_widgets.end())
   {
     std::cerr << G_STRFUNC << ": first was not a first widget. first=" << first << std::endl;
-    return 0; //It has no Box parent because it is not even a first widget.
+    return nullptr; //It has no Box parent because it is not even a first widget.
   }
   
   for(const auto& hbox : m_list_hboxes)
@@ -72,7 +72,7 @@ const Gtk::Box* FlowTable::get_parent_hbox(const Gtk::Widget* first) const
       return hbox;
   }
 
-  return 0;
+  return nullptr;
 }
 
 void FlowTable::delete_and_forget_hbox(Gtk::Box* hbox)
@@ -202,11 +202,6 @@ void FlowTable::remove(Gtk::Widget& first)
 
   Egg::SpreadTableDnd::remove_child(first);
 }
-
-FlowTable::type_const_list_widgets FlowTable::get_first_child_widgets() const
-{
-  return m_list_first_widgets;
-}
   
 bool FlowTable::get_column_for_first_widget(const Gtk::Widget& first, guint& column) const
 {
