@@ -58,12 +58,7 @@ protected:
 
   typedef std::list<const Gtk::Widget*> type_const_list_widgets;
 
-  /** This returns all first widgets added with FlowTable::add().
-   * Gtk::Container::get_children() instead returns internal widgets.
-   */
-  type_const_list_widgets get_first_child_widgets() const;
-
-  virtual bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr) override;
+  bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr) override;
 
 private:
 
