@@ -28,7 +28,6 @@
 #include "layoutwidgetfield.h"
 #include <gtkmm/frame.h>
 #include <gtkmm/builder.h>
-#include <gtkmm/scrolledwindow.h>
 #include <giomm/appinfo.h>
 #include <giomm/simpleactiongroup.h>
 #include <evince-view.h>
@@ -49,29 +48,27 @@ public:
 
   virtual ~ImageGlom();
   
-  virtual void set_layout_item(const std::shared_ptr<LayoutItem>& layout_item, const Glib::ustring& table_name);
+  void set_layout_item(const std::shared_ptr<LayoutItem>& layout_item, const Glib::ustring& table_name) override;
 
-  virtual void set_value(const Gnome::Gda::Value& value);
-  virtual Gnome::Gda::Value get_value() const;
-  virtual bool get_has_original_data() const;
+  void set_value(const Gnome::Gda::Value& value) override;
+  Gnome::Gda::Value get_value() const override;
+  bool get_has_original_data() const override;
 
   //Optionally use this instead of set_value(), to avoid creating an unnecessary Value.
   //void set_pixbuf(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf);
 
   void do_choose_image();
 
-  void set_read_only(bool read_only = true);
+  void set_read_only(bool read_only = true) override;
 
   void on_ev_job_finished(EvJob* job);
   
 private:
   void init();
-  void init_widgets(bool use_evince);
-  void clear_image_from_widgets();
 
-  virtual void on_size_allocate(Gtk::Allocation& allocation);
+  void on_size_allocate(Gtk::Allocation& allocation) override;
 
-  virtual bool on_button_press_event(GdkEventButton *event) override;
+  bool on_button_press_event(GdkEventButton *event) override;
 
   void on_menupopup_activate_open_file();
   void on_menupopup_activate_open_file_with();
@@ -85,7 +82,7 @@ private:
   void on_clipboard_clear();
   void on_clipboard_received_image(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf);
 
-  virtual AppWindow* get_appwindow() const;
+  AppWindow* get_appwindow() const override;
 
   void setup_menu_usermode();
   void show_image_data();
@@ -111,13 +108,12 @@ private:
   Gtk::Frame m_frame;
   
   //For anything supported by Evince:
-  Gtk::ScrolledWindow* m_ev_scrolled_window;
   EvView* m_ev_view;
   EvDocumentModel* m_ev_document_model;
   
   //For anything supported by GdkPixbuf,
   //or for representative thumbnails and icons:
-  Gtk::Image* m_image;
+  Gtk::Image m_image;
   Glib::RefPtr<Gdk::Pixbuf> m_pixbuf_original; //Only stored temporarily, because it could be big.
   Glib::RefPtr<Gdk::Pixbuf> m_pixbuf_clipboard; //When copy is used, store it here until it is pasted.
 
