@@ -31,9 +31,6 @@ namespace Glom
 
 LayoutWidgetBase::LayoutWidgetBase()
 : m_pLayoutItem(nullptr)
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-  , m_drag_in_progress(false)
-#endif // !GLOM_ENABLE_CLIENT_ONLY
 {
 }
 
@@ -59,7 +56,7 @@ std::shared_ptr<LayoutItem> LayoutWidgetBase::get_layout_item()
 
 AppWindow* LayoutWidgetBase::get_appwindow() const
 {
-  return 0; //override to implement.
+  return nullptr; //override to implement.
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -190,16 +187,4 @@ void LayoutWidgetBase::apply_formatting(Gtk::Widget& widget, const std::shared_p
   }
 }
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-void LayoutWidgetBase::set_dnd_in_progress(bool drag)
-{
-  m_drag_in_progress = drag;
-}
-
-bool LayoutWidgetBase::get_dnd_in_progress()
-{
-  return m_drag_in_progress; 
-}
-#endif // !GLOM_ENABLE_CLIENT_ONLY
-
 } //namespace Glom
