@@ -36,11 +36,11 @@ public:
   PlaceHolder(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~PlaceHolder();
 
-  virtual void add(Gtk::Widget& child);
-  virtual void remove();
+  void add(Gtk::Widget& child) override;
+  void remove();
 
-  virtual Gtk::Widget* get_child();
-  virtual const Gtk::Widget* get_child() const;  
+  Gtk::Widget* get_child();
+  const Gtk::Widget* get_child() const;  
 
 private:
   Gtk::Widget* m_pChild;
