@@ -103,10 +103,8 @@ int main(int argc, char* argv[])
     return EXIT_FAILURE;
   }
 
-  #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
   try
   {
-  #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
     xmlpp::DomParser parser;
     //parser.set_validate();
     parser.set_substitute_entities(); //We just want the text to be resolved/unescaped automatically.
@@ -126,14 +124,11 @@ int main(int argc, char* argv[])
        if(child && !attempt_instantiation(filepath, child))
          return EXIT_FAILURE;
     }
-
-  #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
   }
   catch(const std::exception& ex)
   {
     std::cout << "Exception caught: " << ex.what() << std::endl;
   }
-  #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
 
   return EXIT_SUCCESS;
 }
