@@ -41,7 +41,6 @@
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_line.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_imageobject.h>
-#include <glom/mode_design/layout/layout_item_dialogs/dialog_notebook.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_textobject.h>
 #include <glom/mode_design/layout/layout_item_dialogs/box_formatting.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_field_summary.h>
@@ -171,7 +170,6 @@ int main(int argc, char *argv[])
   instantiate_widget<Dialog_SortFields>();
   instantiate_widget<Dialog_Line>();
   instantiate_widget<Dialog_ImageObject>();
-  instantiate_widget<Dialog_Notebook>();
   instantiate_widget<Dialog_FieldSummary>();
   instantiate_widget<Dialog_GroupBy>();
   instantiate_widget<Dialog_IdentifyOriginal>();
